package com.ruoyi.project.training.elearn.service;

import java.util.List;
import com.ruoyi.project.training.elearn.domain.TElLearn;

/**
 * 在线学习记录Service接口
 * 
 * @author ssy
 * @date 2024-06-05
 */
public interface ITElLearnService 
{
    /**
     * 查询在线学习记录
     * 
     * @param id 在线学习记录ID
     * @return 在线学习记录
     */
    public TElLearn selectTElLearnById(Long id);

    /**
     * 查询在线学习记录列表
     * 
     * @param tElLearn 在线学习记录
     * @return 在线学习记录集合
     */
    public List<TElLearn> selectTElLearnList(TElLearn tElLearn);
    public TElLearn selectLearnByUserIdAndResourceId(TElLearn tElLearn);

    /**
     * 新增在线学习记录
     * 
     * @param tElLearn 在线学习记录
     * @return 结果
     */
    public int insertTElLearn(TElLearn tElLearn);

    /**
     * 修改在线学习记录
     * 
     * @param tElLearn 在线学习记录
     * @return 结果
     */
    public int updateTElLearn(TElLearn tElLearn);

    /**
     * 批量删除在线学习记录
     * 
     * @param ids 需要删除的在线学习记录ID
     * @return 结果
     */
    public int deleteTElLearnByIds(Long[] ids);

    /**
     * 删除在线学习记录信息
     * 
     * @param id 在线学习记录ID
     * @return 结果
     */
    public int deleteTElLearnById(Long id);
}
